@@ -1,10 +1,10 @@
 #' Generic function for extracting random effect samples from a model object (BCF, BART, etc...)
-#' 
+#'
 #' @param object Fitted model object from which to extract random effects
 #' @param ... Other parameters to be used in random effects extraction
 #' @return List of random effect samples
 #' @export
-#' 
+#'
 #' @examples
 #' n <- 100
 #' p <- 10
@@ -15,4 +15,6 @@
 #' bart_model <- bart(X_train=X, y_train=y, rfx_group_ids_train=rfx_group_ids,
 #'                    rfx_basis_train = rfx_basis, num_gfr=0, num_mcmc=10)
 #' rfx_samples <- getRandomEffectSamples(bart_model)
-getRandomEffectSamples <- function(object, ...) UseMethod("getRandomEffectSamples")
+getRandomEffectSamples <- function(object, ...) {
+  UseMethod("getRandomEffectSamples")
+}
