@@ -7,9 +7,7 @@
 #include <stochtree/partition_tracker.h>
 #include <stochtree/tree_sampler.h>
 #include <stochtree/variance_model.h>
-#include <functional>
 #include <memory>
-#include <vector>
 
 [[cpp11::register]]
 cpp11::external_pointer<StochTree::TreeEnsemble> active_forest_cpp(int num_trees, int output_dimension = 1, bool is_leaf_constant = true, bool is_exponentiated = false) {
@@ -73,6 +71,21 @@ cpp11::external_pointer<StochTree::ForestContainer> forest_container_from_json_s
     return cpp11::external_pointer<StochTree::ForestContainer>(forest_sample_ptr_.release());
 }
 
+[[cpp11::register]]
+void forest_merge_cpp(cpp11::external_pointer<StochTree::TreeEnsemble> inbound_forest_ptr, cpp11::external_pointer<StochTree::TreeEnsemble> outbound_forest_ptr) {
+    inbound_forest_ptr->MergeForest(*outbound_forest_ptr);
+}
+
+[[cpp11::register]]
+void forest_add_constant_cpp(cpp11::external_pointer<StochTree::TreeEnsemble> forest_ptr, double constant_value) {
+    forest_ptr->AddValueToLeaves(constant_value);
+}
+
+[[cpp11::register]]
+void forest_multiply_constant_cpp(cpp11::external_pointer<StochTree::TreeEnsemble> forest_ptr, double constant_multiple) {
+    forest_ptr->MultiplyLeavesByValue(constant_multiple);
+}
+
 [[cpp11::register]]
 void forest_container_append_from_json_string_cpp(cpp11::external_pointer<StochTree::ForestContainer> forest_sample_ptr, std::string json_string, std::string forest_label) {
     // Create a nlohmann::json object from the string
@@ -85,6 +98,26 @@ void forest_container_append_from_json_string_cpp(cpp11::external_pointer<StochT
     forest_sample_ptr->append_from_json(forest_json);
 }
 
+[[cpp11::register]]
+void combine_forests_forest_container_cpp(cpp11::external_pointer<StochTree::ForestContainer> forest_samples, cpp11::integers forest_inds) {
+    int num_forests = forest_inds.size();
+    for (int j = 1; j < num_forests; j++) {
+        forest_samples->MergeForests(forest_inds[0], forest_inds[j]);
+    }
+    // double combined_forest_scale_factor = 1.0 / num_forests;
+    // forest_samples->MultiplyForest(forest_inds[0], combined_forest_scale_factor);
+}
+
+[[cpp11::register]]
+void add_to_forest_forest_container_cpp(cpp11::external_pointer<StochTree::ForestContainer> forest_samples, int forest_index, double constant_value) {
+    forest_samples->AddToForest(forest_index, constant_value);
+}
+
+[[cpp11::register]]
+void multiply_forest_forest_container_cpp(cpp11::external_pointer<StochTree::ForestContainer> forest_samples, int forest_index, double constant_multiple) {
+    forest_samples->MultiplyForest(forest_index, constant_multiple);
+}
+
 [[cpp11::register]]
 int num_samples_forest_container_cpp(cpp11::external_pointer<StochTree::ForestContainer> forest_samples) {
     return forest_samples->NumSamples();
@@ -737,8 +770,9 @@ cpp11::writable::integers get_overall_split_counts_active_forest_cpp(cpp11::exte
         StochTree::Tree* tree = active_forest->GetTree(i);
         std::vector<int32_t> split_nodes = tree->GetInternalNodes();
         for (int j = 0; j < split_nodes.size(); j++) {
-            auto split_feature = split_nodes.at(j);
-            output.at(split_feature)++;
+            auto node_id = split_nodes.at(j);
+            auto feature_split = tree->SplitIndex(node_id);
+            output.at(feature_split)++;
         }
     }
     return output;
@@ -753,8 +787,9 @@ cpp11::writable::integers get_granular_split_count_array_active_forest_cpp(cpp11
         StochTree::Tree* tree = active_forest->GetTree(i);
         std::vector<int32_t> split_nodes = tree->GetInternalNodes();
         for (int j = 0; j < split_nodes.size(); j++) {
-            auto split_feature = split_nodes.at(j);
-            output.at(split_feature*num_trees + i)++;
+            auto node_id = split_nodes.at(j);
+            auto feature_split = tree->SplitIndex(node_id);
+            output.at(feature_split*num_trees + i)++;
         }
     }
     return output;
